package javax.swing;

import javax.swing.text.AttributeSet;
import java.awt.Rectangle;
import java.awt.Point;
import javax.accessibility.AccessibleValue;
import javax.accessibility.AccessibleComponent;
import java.awt.IllegalComponentStateException;
import java.util.Locale;
import javax.accessibility.AccessibleStateSet;
import javax.accessibility.AccessibleRole;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.accessibility.AccessibleText;
import java.awt.Container;
import java.awt.Window;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import java.awt.BorderLayout;
import java.awt.Dialog;
import java.awt.Frame;
import javax.accessibility.AccessibleContext;
import java.awt.Component;
import javax.accessibility.Accessible;

public class ProgressMonitor implements Accessible
{
    private ProgressMonitor root;
    private JDialog dialog;
    private JOptionPane pane;
    private JProgressBar myBar;
    private JLabel noteLabel;
    private Component parentComponent;
    private String note;
    private Object[] cancelOption;
    private Object message;
    private long T0;
    private int millisToDecideToPopup;
    private int millisToPopup;
    private int min;
    private int max;
    protected AccessibleContext accessibleContext;
    private AccessibleContext accessibleJOptionPane;
    
    public ProgressMonitor(Component component, Object o, String s, int n, int n2) {
        this(component, o, s, n, n2, null);
    }
    
    private ProgressMonitor(Component parentComponent, Object message, String note, int min, int max, ProgressMonitor progressMonitor) {
        this.cancelOption = null;
        this.millisToDecideToPopup = 500;
        this.millisToPopup = 2000;
        this.accessibleContext = null;
        this.accessibleJOptionPane = null;
        this.min = min;
        this.max = max;
        this.parentComponent = parentComponent;
        (this.cancelOption = new Object[1])[0] = UIManager.getString("OptionPane.cancelButtonText");
        this.message = message;
        this.note = note;
        if (progressMonitor != null) {
            this.root = ((progressMonitor.root != null) ? progressMonitor.root : progressMonitor);
            this.T0 = this.root.T0;
            this.dialog = this.root.dialog;
        }
        else {
            this.T0 = System.currentTimeMillis();
        }
    }
    
    public void setProgress(int n) {
        if (n >= this.max) {
            this.close();
        }
        else if (this.myBar != null) {
            this.myBar.setValue(n);
        }
        else {
            long n2 = (long)(int)(System.currentTimeMillis() - this.T0);
            if (n2 >= (long)this.millisToDecideToPopup) {
                int millisToPopup;
                if (n > this.min) {
                    millisToPopup = (int)(n2 * (long)(this.max - this.min) / (long)(n - this.min));
                }
                else {
                    millisToPopup = this.millisToPopup;
                }
                if (millisToPopup >= this.millisToPopup) {
                    (this.myBar = new JProgressBar()).setMinimum(this.min);
                    this.myBar.setMaximum(this.max);
                    this.myBar.setValue(n);
                    if (this.note != null) {
                        this.noteLabel = new JLabel(this.note);
                    }
                    this.pane = new ProgressMonitor.ProgressOptionPane(new Object[] { this.message, this.noteLabel, this.myBar });
                    (this.dialog = this.pane.createDialog(this.parentComponent, UIManager.getString("ProgressMonitor.progressText"))).show();
                }
            }
        }
    }
    
    public void close() {
        if (this.dialog != null) {
            this.dialog.setVisible(false);
            this.dialog.dispose();
            this.dialog = null;
            this.pane = null;
            this.myBar = null;
        }
    }
    
    public int getMinimum() {
        return this.min;
    }
    
    public void setMinimum(int n) {
        if (this.myBar != null) {
            this.myBar.setMinimum(n);
        }
        this.min = n;
    }
    
    public int getMaximum() {
        return this.max;
    }
    
    public void setMaximum(int n) {
        if (this.myBar != null) {
            this.myBar.setMaximum(n);
        }
        this.max = n;
    }
    
    public boolean isCanceled() {
        if (this.pane == null) {
            return false;
        }
        Object value = this.pane.getValue();
        return value != null && this.cancelOption.length == 1 && value.equals(this.cancelOption[0]);
    }
    
    public void setMillisToDecideToPopup(int millisToDecideToPopup) {
        this.millisToDecideToPopup = millisToDecideToPopup;
    }
    
    public int getMillisToDecideToPopup() {
        return this.millisToDecideToPopup;
    }
    
    public void setMillisToPopup(int millisToPopup) {
        this.millisToPopup = millisToPopup;
    }
    
    public int getMillisToPopup() {
        return this.millisToPopup;
    }
    
    public void setNote(String s) {
        this.note = s;
        if (this.noteLabel != null) {
            this.noteLabel.setText(s);
        }
    }
    
    public String getNote() {
        return this.note;
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new ProgressMonitor.AccessibleProgressMonitor();
        }
        if (this.pane != null && this.accessibleJOptionPane == null && this.accessibleContext instanceof ProgressMonitor.AccessibleProgressMonitor) {
            ProgressMonitor.AccessibleProgressMonitor.access$100((ProgressMonitor.AccessibleProgressMonitor)this.accessibleContext);
        }
        return this.accessibleContext;
    }
    
    private class ProgressOptionPane extends JOptionPane
    {
        ProgressOptionPane(Object o) {
            super(o, 1, -1, null, ProgressMonitor.this.cancelOption, null);
        }
        
        @Override
        public int getMaxCharactersPerLineCount() {
            return 60;
        }
        
        @Override
        public JDialog createDialog(Component locationRelativeTo, String s) {
            Window windowForComponent = JOptionPane.getWindowForComponent(locationRelativeTo);
            JDialog dialog;
            if ((windowForComponent instanceof Frame)) {
                dialog = new JDialog((Frame)windowForComponent, s, false);
            }
            else {
                dialog = new JDialog((Dialog)windowForComponent, s, false);
            }
            if ((windowForComponent instanceof SwingUtilities.SharedOwnerFrame)) {
                dialog.addWindowListener(SwingUtilities.getSharedOwnerFrameShutdownListener());
            }
            Container contentPane = dialog.getContentPane();
            contentPane.setLayout(new BorderLayout());
            contentPane.add(this, "Center");
            dialog.pack();
            dialog.setLocationRelativeTo(locationRelativeTo);
            dialog.addWindowListener(new WindowAdapter() {
                boolean gotFocus = false;
                
                @Override
                public void windowClosing(WindowEvent windowEvent) {
                    ProgressMonitor.ProgressOptionPane.this.setValue(ProgressMonitor.this.cancelOption[0]);
                }
                
                @Override
                public void windowActivated(WindowEvent windowEvent) {
                    if (!this.gotFocus) {
                        ProgressMonitor.ProgressOptionPane.this.selectInitialValue();
                        this.gotFocus = true;
                    }
                }
            });
            this.addPropertyChangeListener(new PropertyChangeListener() {
                @Override
                public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
                    if (dialog.isVisible() && propertyChangeEvent.getSource() == ProgressMonitor.ProgressOptionPane.this && (propertyChangeEvent.getPropertyName().equals("value") || propertyChangeEvent.getPropertyName().equals("inputValue"))) {
                        dialog.setVisible(false);
                        dialog.dispose();
                    }
                }
            });
            return dialog;
        }
        
        @Override
        public AccessibleContext getAccessibleContext() {
            return ProgressMonitor.this.getAccessibleContext();
        }
        
        private AccessibleContext getAccessibleJOptionPane() {
            return super.getAccessibleContext();
        }
        
        static AccessibleContext access$400(ProgressMonitor.ProgressOptionPane progressOptionPane) {
            return progressOptionPane.getAccessibleJOptionPane();
        }
    }
    
    protected class AccessibleProgressMonitor extends AccessibleContext implements AccessibleText, ChangeListener, PropertyChangeListener
    {
        private Object oldModelValue;
        
        private void optionPaneCreated() {
            ProgressMonitor.this.accessibleJOptionPane = ProgressMonitor.ProgressOptionPane.access$400((ProgressMonitor.ProgressOptionPane)ProgressMonitor.this.pane);
            if (ProgressMonitor.this.myBar != null) {
                ProgressMonitor.this.myBar.addChangeListener(this);
            }
            if (ProgressMonitor.this.noteLabel != null) {
                ProgressMonitor.this.noteLabel.addPropertyChangeListener(this);
            }
        }
        
        @Override
        public void stateChanged(ChangeEvent changeEvent) {
            if (changeEvent == null) {
                return;
            }
            if (ProgressMonitor.this.myBar != null) {
                Integer value = Integer.valueOf(ProgressMonitor.this.myBar.getValue());
                this.firePropertyChange("AccessibleValue", this.oldModelValue, value);
                this.oldModelValue = value;
            }
            return;
        }
        
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            if (propertyChangeEvent.getSource() == ProgressMonitor.this.noteLabel && propertyChangeEvent.getPropertyName() == "text") {
                this.firePropertyChange("AccessibleText", null, Integer.valueOf(0));
            }
        }
        
        @Override
        public String getAccessibleName() {
            if (this.accessibleName != null) {
                return this.accessibleName;
            }
            if (ProgressMonitor.this.accessibleJOptionPane != null) {
                return ProgressMonitor.this.accessibleJOptionPane.getAccessibleName();
            }
            return null;
        }
        
        @Override
        public String getAccessibleDescription() {
            if (this.accessibleDescription != null) {
                return this.accessibleDescription;
            }
            if (ProgressMonitor.this.accessibleJOptionPane != null) {
                return ProgressMonitor.this.accessibleJOptionPane.getAccessibleDescription();
            }
            return null;
        }
        
        @Override
        public AccessibleRole getAccessibleRole() {
            return AccessibleRole.PROGRESS_MONITOR;
        }
        
        @Override
        public AccessibleStateSet getAccessibleStateSet() {
            if (ProgressMonitor.this.accessibleJOptionPane != null) {
                return ProgressMonitor.this.accessibleJOptionPane.getAccessibleStateSet();
            }
            return null;
        }
        
        @Override
        public Accessible getAccessibleParent() {
            return ProgressMonitor.this.dialog;
        }
        
        private AccessibleContext getParentAccessibleContext() {
            if (ProgressMonitor.this.dialog != null) {
                return ProgressMonitor.this.dialog.getAccessibleContext();
            }
            return null;
        }
        
        @Override
        public int getAccessibleIndexInParent() {
            if (ProgressMonitor.this.accessibleJOptionPane != null) {
                return ProgressMonitor.this.accessibleJOptionPane.getAccessibleIndexInParent();
            }
            return -1;
        }
        
        @Override
        public int getAccessibleChildrenCount() {
            AccessibleContext panelAccessibleContext = this.getPanelAccessibleContext();
            if (panelAccessibleContext != null) {
                return panelAccessibleContext.getAccessibleChildrenCount();
            }
            return 0;
        }
        
        @Override
        public Accessible getAccessibleChild(int n) {
            AccessibleContext panelAccessibleContext = this.getPanelAccessibleContext();
            if (panelAccessibleContext != null) {
                return panelAccessibleContext.getAccessibleChild(n);
            }
            return null;
        }
        
        private AccessibleContext getPanelAccessibleContext() {
            if (ProgressMonitor.this.myBar != null) {
                Container parent = ProgressMonitor.this.myBar.getParent();
                if ((parent instanceof Accessible)) {
                    return parent.getAccessibleContext();
                }
            }
            return null;
        }
        
        @Override
        public Locale getLocale() throws IllegalComponentStateException {
            if (ProgressMonitor.this.accessibleJOptionPane != null) {
                return ProgressMonitor.this.accessibleJOptionPane.getLocale();
            }
            return null;
        }
        
        @Override
        public AccessibleComponent getAccessibleComponent() {
            if (ProgressMonitor.this.accessibleJOptionPane != null) {
                return ProgressMonitor.this.accessibleJOptionPane.getAccessibleComponent();
            }
            return null;
        }
        
        @Override
        public AccessibleValue getAccessibleValue() {
            if (ProgressMonitor.this.myBar != null) {
                return ProgressMonitor.this.myBar.getAccessibleContext().getAccessibleValue();
            }
            return null;
        }
        
        @Override
        public AccessibleText getAccessibleText() {
            if (this.getNoteLabelAccessibleText() != null) {
                return this;
            }
            return null;
        }
        
        private AccessibleText getNoteLabelAccessibleText() {
            if (ProgressMonitor.this.noteLabel != null) {
                return ProgressMonitor.this.noteLabel.getAccessibleContext().getAccessibleText();
            }
            return null;
        }
        
        @Override
        public int getIndexAtPoint(Point point) {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null && this.sameWindowAncestor(ProgressMonitor.this.pane, ProgressMonitor.this.noteLabel)) {
                Point convertPoint = SwingUtilities.convertPoint(ProgressMonitor.this.pane, point, ProgressMonitor.this.noteLabel);
                if (convertPoint != null) {
                    return noteLabelAccessibleText.getIndexAtPoint(convertPoint);
                }
            }
            return -1;
        }
        
        @Override
        public Rectangle getCharacterBounds(int n) {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null && this.sameWindowAncestor(ProgressMonitor.this.pane, ProgressMonitor.this.noteLabel)) {
                Rectangle characterBounds = noteLabelAccessibleText.getCharacterBounds(n);
                if (characterBounds != null) {
                    return SwingUtilities.convertRectangle(ProgressMonitor.this.noteLabel, characterBounds, ProgressMonitor.this.pane);
                }
            }
            return null;
        }
        
        private boolean sameWindowAncestor(Component component, Component component2) {
            return component != null && component2 != null && SwingUtilities.getWindowAncestor(component) == SwingUtilities.getWindowAncestor(component2);
        }
        
        @Override
        public int getCharCount() {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null) {
                return noteLabelAccessibleText.getCharCount();
            }
            return -1;
        }
        
        @Override
        public int getCaretPosition() {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null) {
                return noteLabelAccessibleText.getCaretPosition();
            }
            return -1;
        }
        
        @Override
        public String getAtIndex(int n, int n2) {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null) {
                return noteLabelAccessibleText.getAtIndex(n, n2);
            }
            return null;
        }
        
        @Override
        public String getAfterIndex(int n, int n2) {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null) {
                return noteLabelAccessibleText.getAfterIndex(n, n2);
            }
            return null;
        }
        
        @Override
        public String getBeforeIndex(int n, int n2) {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null) {
                return noteLabelAccessibleText.getBeforeIndex(n, n2);
            }
            return null;
        }
        
        @Override
        public AttributeSet getCharacterAttribute(int n) {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null) {
                return noteLabelAccessibleText.getCharacterAttribute(n);
            }
            return null;
        }
        
        @Override
        public int getSelectionStart() {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null) {
                return noteLabelAccessibleText.getSelectionStart();
            }
            return -1;
        }
        
        @Override
        public int getSelectionEnd() {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null) {
                return noteLabelAccessibleText.getSelectionEnd();
            }
            return -1;
        }
        
        @Override
        public String getSelectedText() {
            AccessibleText noteLabelAccessibleText = this.getNoteLabelAccessibleText();
            if (noteLabelAccessibleText != null) {
                return noteLabelAccessibleText.getSelectedText();
            }
            return null;
        }
        
        static void access$100(ProgressMonitor.AccessibleProgressMonitor accessibleProgressMonitor) {
            accessibleProgressMonitor.optionPaneCreated();
        }
    }
}
